BeaconController class abstract mixin

An abstract mixin class that automatically disposes all beacons created by this controller.

Implemented types

Constructors

BeaconController()

Properties

B BeaconGroup
Local BeaconCreator that automatically disposes all beacons created by this controller.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → void
Disposes all beacons created by this controller.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited